pub fn validate(plan: &Plan, config: &Config) -> ParseResultExpand description
Validates the given substrait Plan message and returns the parse tree and diagnostic results.
pub fn validate(plan: &Plan, config: &Config) -> ParseResultValidates the given substrait Plan message and returns the parse tree and diagnostic results.