pub struct Aggregate {
pub arguments: Vec<Argument>,
pub name: String,
pub description: Option<Description>,
pub deterministic: bool,
pub session_dependent: bool,
pub output_type: Option<DerivationExpression>,
pub ordered: bool,
pub max_set: u64,
pub intermediate_type: Option<Type>,
pub implementations: Vec<Implementation>,
pub final_variable_behavior: Option<FinalVariableBehavior>,
}Fields
arguments: Vec<Argument>name: Stringdescription: Option<Description>deterministic: boolsession_dependent: booloutput_type: Option<DerivationExpression>ordered: boolmax_set: u64intermediate_type: Option<Type>implementations: Vec<Implementation>final_variable_behavior: Option<FinalVariableBehavior>Trait Implementations
Sourceimpl InputNode for Aggregate
impl InputNode for Aggregate
Sourcefn type_to_node() -> Node
fn type_to_node() -> Node
Creates an empty output node for a protobuf datum of this type. Read more
Sourcefn data_to_node(&self) -> Node
fn data_to_node(&self) -> Node
Creates an empty output node for a protobuf datum with this value.
Sourcefn oneof_variant(&self) -> Option<&'static str>
fn oneof_variant(&self) -> Option<&'static str>
Returns the name of the selected variant of a oneof field, if this
is a rust enum used to represent a oneof field.
Sourcefn parse_unknown(&self, y: &mut Context<'_>) -> bool
fn parse_unknown(&self, y: &mut Context<'_>) -> bool
Complete the subtrees of this datum in output that have not already
been parsed using UnknownField nodes. Returns whether any such nodes
were added.
Sourceimpl Message for Aggregate
impl Message for Aggregate
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl ProtoMessage for Aggregate
impl ProtoMessage for Aggregate
Sourcefn proto_message_type() -> &'static str
fn proto_message_type() -> &'static str
Returns the protobuf type name for messages of this type.
impl StructuralPartialEq for Aggregate