Module yaml

Module yaml 

Module for representing YAML input.

We (ab)use serde_json::value::Value for this; the primary reason being that a JSON schema is used for basic schema validation of the YAML files, and the jsonschema crate we use for that uses serde_json’s representation). yaml_to_json() may be used to convert the output from serde_yaml to this structure.

Functions

yaml_to_json
Converts a serde_yaml YAML structure into its equivalent JSON object model using serde_json’s types.

Type Aliases

Array
Typedef for the type used for YAML arrays.
Map
Typedef for the type used for YAML maps.
Value
Type for the type used for arbitrary YAML values.