pub struct Cause {
pub message: Arc<Message>,
pub classification: Classification,
}Expand description
Description of the cause of a diagnostic.
Fields
message: Arc<Message>The error message. Within this crate we don’t bother typing these beyond the Classification enum, but we do retain typing information for messages from other crates.
classification: ClassificationClassification of this cause. This attaches an error code and generic message for said code to the diagnostic message. The user can use these codes to for instance always promote a particular type of diagnostic to an error (like gcc -Werror).
Implementations