Definition

Struct Definition 

pub struct Definition<T> { /* private fields */ }
Nested namespace structure.

There are a lot of things “weird” about this structure, because Substrait is defined horribly; everything is a valid identifier (including identifiers with periods in them, so a period is ambiguous between a namespace separator and just part of an identifier), matching is case-insensitive (but for the validator we do want to store what the user’s case convention was for a definition), and for type variations names need not even be unique (arguably there’s a different variation namespace for each type class, but the type class isn’t yet known when a type variation anchor is defined, and that’s where we want to resolve the name; see https://github.com/substrait-io/substrait/issues/268).

So here we have an abomination of a namespace system that allows for name conflicts and period ambiguity and just tries to deal with it as cleanly as it can.

Implementations

Source

impl<T> Definition<T>

pub fn new() -> Self

Creates a new, empty namespace.

pub fn define_item<S: AsRef<str>>( &mut self, name: S, item: Arc<T>, public: bool, )

Defines an item with the given (case-insensitive) name. If an item going by a conflicting name already existed, the new item is inserted anyway; if the caller is concerned about that, it must first resolve the name and throw a warning or error based on its result.

pub fn define_nested<S: AsRef<str>>( &mut self, name: S, item: Option<Reference<T>>, public: bool, )

Registers a nested namespace with the given (case-insensitive) name. Same rules for duplicates as define_item(). If None is specified for item, the namespace reference is registered, but its contents are left unspecified.

pub fn resolve_local<R>(&self, reference: R) -> ResolutionResult<T>
where R: Into<Data<T>>,

Resolves a name to all items with the same name visible from within this namespace (so, including private items).

pub fn resolve_public<R>(&self, reference: R) -> ResolutionResult<T>
where R: Into<Data<T>>,

Resolves a name to all items with the same name visible from outside this namespace (so, excluding private items).