Module path

Module path 

Module for handling tree paths.

The PathElement, Path, and PathBuf types are used to uniquely refer to any node in a Substrait plan (or, more accurately, any combination of protobuf and YAML data). Path, and PathBuf work roughly the same as std::path::Path, and std::path::PathBuf, but for protobuf/YAML tree paths rather than filesystem paths.

Structs

PathBuf
Refers to a location within a protobuf message.

Enums

Path
Used to track a location within a protobuf message. The owned version is PathBuf.
PathElement
Element of a path to some field of a protobuf message and/or YAML file.